UNIMOD='''C0H0N0O0S0	1_neutr_nterm	1
C0H0N0O0S0	2_neutr_nterm	2
C0H0N0O0S0	3_neutr_nterm	3
C0H0N0O0S0	4_neutr_cterm	4
C0H0N0O0S0	5_neutr_cterm	5
C0H0N0O0S0	6_neutr_cterm	6
C0H0N0O0S0	1x13CN	1
C0H0N0O0S0	2x13C_NTerm	2
C0H0N0O0S0	3X13C_NTerm	3
C0H0N0O0S0	4x13C_NTerm	4
C0H0N0O0S0	5x13C_NTerm	5
C0H0N0O0S0	6x13C_NTerm	6
C0H0N0O0S0	2x13C_CTerm	2
C0H0N0O0S0	3x13C_CTerm	3
C0H0N0O0S0	4x13C_CTerm	4
C0H0N0O0S0	5x13C_CTerm	5
C0H0N0O0S0	6x13C_CTerm	6
C2H2N0O1S0	Acetyl
C0H1N1O-1S0	Amidated
C10H14N2O2S1	Biotin
C2H3N1O1S0	Carbamidomethyl
C1H1N1O1S0	Carbamyl
C2H2N0O2S0	Carboxymethyl
C0H-1N-1O1S0	Deamidated
C22H38N4O6S1	ICAT-G
C-1H-2N0O1S-1	Met->Hse
C-1H-4N0O0S-1	Met->Hsl
C20H34N4O5S1	ICAT-D
C5H9N1O1S0	NIPCAM
C18H30N4O5S1	PEO-Iodoacetyl-LC-Biotin
C0H-2N0O-1S0	Dehydrated
C3H5N1O1S0	Propionamide
C7H5N1O1S0	Pyridylacetyl
C2H0N0O1S0	Pyro-carbamidomethyl
C0H-2N0O-1S0	Glu->pyro-Glu
C0H-3N-1O0S0	Gln->pyro-Glu
C6H9N1O2S0	SMA
C7H7N1O0S0	Pyridylethyl
C1H2N0O0S0	Methyl
C0H0N0O1S0	Oxidation
C2H4N0O0S0	Dimethyl
C3H6N0O0S0	Trimethyl
C1H2N0O0S1	Methylthio
C0H0N0O3S1	Sulfo
C6H10N0O5S0	Hex
C8H12N0O1S2	Lipoyl
C8H13N1O5S0	HexNAc
C15H24N0O0S0	Farnesyl
C14H26N0O1S0	Myristoyl
C16H30N0O1S0	Palmitoyl
C20H32N0O0S0	GeranylGeranyl
C51H96N0O5S0	Tripalmitate
C1H2N2O0S0	Guanidinyl
C9H16N0O2S0	HNE
C6H8N0O6S0	Glucuronyl
C10H15N3O6S1	Glutathione
C3H4N0O1S0	Propionyl
C13H31N3O1S0	GIST-Quat
C4H4N0O3S0	Succinyl
C10H18N4O2S1	probiotinhydrazide
C0H-2N0O1S0	Pro->pyro-Glu
C-2H-1N-1O1S0	His->Asn
C-2H-2N-2O2S0	His->Asp
C-1H0N0O2S0	Trp->Hydroxykynurenin
C3H4N0O0S0	Delta:H(4)C(3)
C2H4N0O0S0	Delta:H(4)C(2)
C0H-2N0O0S-1	Cys->Dha
C-1H-5N-3O1S0	Arg->GluSA
C0H0N0O3S0	Trioxidation
C10H15N3O1S1	Iminobiotin
C16H26N4O2S1	ESP
C16H25N3O3S1	NHS-LC-Biotin
C25H39N5O6S3	EDT-maleimide-PEO-biotin
C3H4N2O0S0	IMID
C10H15N3O2S1	Lysbiotinhydrazide
C0H-1N1O2S0	Nitro
C10H17N3O3S0	ICAT-C
C2H2N0O0S0	Delta:H(2)C(2)
C-1H0N0O1S0	Trp->Kynurenin
C0H-3N-1O1S0	Lys->Allysine
C6H9N1O2S1	FormylMet
C6H7N1O2S0	Nethylmaleimide
C16H26N4O3S1	OxLysBiotinRed
C16H24N4O3S1	OxLysBiotin
C16H29N5O3S1	OxProBiotinRed
C16H27N5O3S1	OxProBiotin
C15H22N2O3S1	OxArgBiotin
C15H24N2O3S1	OxArgBiotinRed
C20H34N4O4S3	EDT-iodoacetyl-PEO-biotin
C4H6N2O2S0	GG
C1H0N0O1S0	Formyl
C3H4N0O1S1	Xlink:DTSSP[88]
C10H10N0O6S0	Xlink:EGS[226]
C22H13N1O6S0	Fluorescein
C14H24N0O1S0	Myristoleyl
C-1H-2N0O-1S0	Pro->Pyrrolidinone
C14H22N0O1S0	Myristoyl+Delta:H(-4)
C7H4N0O1S0	Benzoyl
C46H76N2O35S0	Hex(5)HexNAc(2)
C12H11N1O2S1	Dansyl
C-1H-2N0O-2S0	a-type-ion
C2H3N1O0S0	Amidine
C14H23N1O9S0	HexNAc(1)dHex(1)
C16H26N2O10S0	HexNAc(2)
C18H30N0O15S0	Hex(3)
C20H33N1O13S0	HexNAc(1)dHex(2)
C20H33N1O14S0	Hex(1)HexNAc(1)dHex(1)
C22H36N2O14S0	HexNAc(2)dHex(1)
C22H36N2O15S0	Hex(1)HexNAc(2)
C25H40N2O18S0	Hex(1)HexNAc(1)NeuAc(1)
C28H46N2O18S0	HexNAc(2)dHex(2)
C27H44N2O19S0	Hex(1)HexNAc(2)Pent(1)
C28H46N2O19S0	Hex(1)HexNAc(2)dHex(1)
C28H46N2O20S0	Hex(2)HexNAc(2)
C31H51N1O24S0	Hex(3)HexNAc(1)Pent(1)
C33H54N2O23S0	Hex(1)HexNAc(2)dHex(1)Pent(1)
C34H56N2O23S0	Hex(1)HexNAc(2)dHex(2)
C33H54N2O24S0	Hex(2)HexNAc(2)Pent(1)
C34H56N2O24S0	Hex(2)HexNAc(2)dHex(1)
C34H56N2O25S0	Hex(3)HexNAc(2)
C36H57N3O26S0	Hex(1)HexNAc(1)NeuAc(2)
C6H3N1O2S1	NBS
C9H19N2O1S0	QAT
C15H22N0O1S0	BHT
C2H4N0O-1S1	Delta:H(4)C(2)O(-1)S(1)
C4H9N1O-1S1	DAET
C-1H0N0O-1S0	Pro->Pyrrolidone
C8H4N0O2S0	HPG
C16H10N0O5S0	2HPG
C10H6N2O1S0	AccQTag
C10H20N2O1S0	EQAT
C2H4N0O-1S2	Ethanedithiol
C6H6N0O1S0	Delta:H(6)C(6)O(1)
C3H4N0O1S0	Delta:H(4)C(3)O(1)
C3H2N0O0S0	Delta:H(2)C(3)
C6H4N0O0S0	Delta:H(4)C(6)
C6H8N0O2S0	Delta:H(8)C(6)O(2)
C4H7N1O1S0	NEIAA
C4H6N0O1S0	Crotonaldehyde
C0H1N1O0S0	Amino
C9H13N1O2S1	Argbiotinhydrazide
C7H5N1O3S2	SPITC
C19H22N0O7S0	Cytopiloyne
C19H24N0O8S0	Cytopiloyne+water
C7H7N1O-1S1	PET
C3H4N0O4S1	CAF
C5H4N0O2S0	Xlink:BS2G[96]
C0H-1N1O1S0	Nitrosyl
C8H9N1O2S1	AEBS
C2H4N0O1S0	Ethanolyl
C4H6N0O2S0	HMVK
C2H4N0O0S0	Ethyl
C1H1N-1O1S0	Methyl+Deamidated
C2H5N0O0S0	Delta:H(5)C(2)
C6H5N1O2S1	SulfanilicAcid
C16H28N4O3S1	Biotin-PEO-Amine
C0H-2N0O1S0	Trp->Oxolactone
C19H32N4O3S2	Biotin-HPDP
C5H7N1O2S1	CAMthiopropanoyl
C14H22N4O3S1	IED-Biotin
C6H10N0O4S0	dHex
C1H0N0O2S0	Carboxy
C10H10N2O2S0	Bromobimane
C11H6N0O2S0	Menadione
C2H4N0O1S1	DeStreak
C56H92N4O39S0	dHex(1)Hex(3)HexNAc(4)
C62H102N4O44S0	dHex(1)Hex(4)HexNAc(4)
C68H112N4O49S0	dHex(1)Hex(5)HexNAc(4)
C50H82N4O35S0	Hex(3)HexNAc(4)
C56H92N4O40S0	Hex(4)HexNAc(4)
C62H102N4O45S0	Hex(5)HexNAc(4)
C3H5N1O2S1	Cysteinyl
C-6H-12N-2O-1S0	Lys-loss
C5H5N1O2S0	Nmethylmaleimide
C37H44N4O6S1	CyDye-Cy3
C6H6N0O0S0	DimethylpyrroleAdduct
C5H2N0O0S0	Delta:H(2)C(5)
C3H2N0O1S0	Delta:H(2)C(3)O(1)
C6H9N1O3S0	Nethylmaleimide+water
C3H5N1O0S1	Xlink:DTBP[87]
C9H18N0O2S0	HNE+Delta:H(2)
C10H16N4O1S1	Thrbiotinhydrazide
C1H3N1O-1S0	Methylamine
C6H11N1O3S2	CarbamidomethylDTT
C6H3N1O1S0	ICPL
C-1H-2N-2O0S0	Arg->Orn
C0H-1N0O0S0	Dehydro
C7H14N2O1S0	Diphthamide
C15H24N0O1S0	Hydroxyfarnesyl
C37H68N0O4S0	Diacylglycerol
C3H4N0O2S0	Carboxyethyl
C4H9N1O1S0	Hypusine
C20H26N0O0S0	Retinylidene
C0H-3N-1O2S0	Lys->AminoadipicAcid
C0H-3N-1O1S-1	Cys->PyruvicAcid
C0H-3N-1O0S0	Ammonia-loss
C33H38N4O6S0	Phycocyanobilin
C33H40N4O6S0	Phycoerythrobilin
C33H36N4O6S0	Phytochromobilin
C0H-2N0O2S0	Quinone
C12H20N0O11S0	Glucosylgalactosyl
C-6H-6N0O-1S0	Tyr->Dha
C0H-2N0O0S0	Didehydro
C0H-2N0O1S-1	Cys->Oxoalanine
C0H-1N-1O0S0	Ser->LacticAcid
C10H14N2O6S0	GluGlu
C5H7N1O3S0	Glu
C9H6N0O2S0	Hydroxycinnamyl
C5H8N0O5S0	Glycosyl
C43H86N0O2S0	Archaeol
C7H5N1O1S0	Phenylisocyanate
C1H2N0O1S0	Hydroxymethyl
C20H22N2O8S0	Dipyrrolylmethanemethyl
C0H0N0O-1S1	Carboxy->Thiocarboxy
C0H0N0O0S1	Sulfide
C3H2N0O2S0	PyruvicAcidIminyl
C0H0N0O2S0	Dioxidation
C8H14N0O1S0	Octanoyl
C16H28N0O1S0	Palmitoleyl
C27H44N0O0S0	Cholesterol
C20H24N0O0S0	Didehydroretinylidene
C17H26N0O4S0	CHDH
C6H7N1O1S0	Methylpyrroline
C1H-1N1O0S0	Cyano
C1H2N2O0S0	Amidino
C3H7N0O1S0	Hydroxytrimethyl
C0H0N0O-1S0	Deoxy
C36H37N3O20S0	Microcin
C10H18N0O1S0	Decanoyl
C15H21N3O9S0	GluGluGlu
C20H28N4O12S0	GluGluGluGlu
C6H11N1O4S0	HexN
C8H14N2O1S0	Xlink:DMP[154]
C13H5N1O0S0	NDA
C13H32N3O1S0	TMAB
C21H15N3O5S1	FTC
C2H5N1O-1S1	AEC-MAEC
C21H24N0O4S0	BADGE
C28H48N0O24S0	Hep
C38H44N4O6S1	CyDye-Cy5
C8H8N1O0S0	DHP
C15H22N0O2S0	BHTOH
C5H7N1O3S0	Nmethylmaleimide+water
C7H6N2O1S0	PyMIC
C20H28N0O4S0	LG-lactam-K
C32H22N2O6S2	BisANS
C5H8N0O0S0	Piperidine
C4H8N0O0S0	Diethyl
C20H28N0O5S0	LG-Hlactam-K
C14H29N1O1S0	C8-QAT
C12H20N0O10S0	Hex(2)
C19H26N-2O4S0	LG-lactam-R
C28H38N0O6S0	Withaferin
C19H26N-2O5S0	LG-Hlactam-R
C23H35N5O7S1	Maleimide-PEO2-Biotin
C22H36N4O4S1	Sulfo-NHS-LC-LC-Biotin
C24H13N1O7S0	FNEM
C9H14N1O4S1	PropylNAGthiazoline
C-1H-4N0O0S-1	Dethiomethyl
C16H29N7O4S0	LRGG
C35H54N4O4S1	Biotin:Cayman-10141
C36H60N4O5S1	Biotin:Cayman-10013
C0H0N0O1S0	Ala->Ser
C1H2N0O1S0	Ala->Thr
C1H0N0O2S0	Ala->Asp
C2H2N0O0S0	Ala->Pro
C-1H-2N0O0S0	Ala->Gly
C2H2N0O2S0	Ala->Glu
C2H4N0O0S0	Ala->Val
C6H4N0O0S-1	Cys->Phe
C0H0N0O1S-1	Cys->Ser
C8H5N1O0S-1	Cys->Trp
C6H4N0O1S-1	Cys->Tyr
C3H7N3O0S-1	Cys->Arg
C-1H-2N0O0S-1	Cys->Gly
C-1H0N0O-2S0	Asp->Ala
C2H2N2O-2S0	Asp->His
C0H1N1O-1S0	Asp->Asn
C-2H-2N0O-2S0	Asp->Gly
C5H4N0O-1S0	Asp->Tyr
C1H2N0O0S0	Asp->Glu
C1H4N0O-2S0	Asp->Val
C-2H-2N0O-2S0	Glu->Ala
C0H1N1O-1S0	Glu->Gln
C-1H-2N0O0S0	Glu->Asp
C1H5N1O-2S0	Glu->Lys
C-3H-4N0O-2S0	Glu->Gly
C0H2N0O-2S0	Glu->Val
C-6H-4N0O1S0	Phe->Ser
C-6H-4N0O0S1	Phe->Cys
C-3H2N0O0S0	Phe->Xle
C0H0N0O1S0	Phe->Tyr
C-4H0N0O0S0	Phe->Val
C1H2N0O0S0	Gly->Ala
C1H2N0O1S0	Gly->Ser
C9H7N1O0S0	Gly->Trp
C3H4N0O2S0	Gly->Glu
C3H6N0O0S0	Gly->Val
C2H2N0O2S0	Gly->Asp
C1H2N0O0S1	Gly->Cys
C4H9N3O0S0	Gly->Arg
C-1H0N-2O0S0	His->Pro
C3H2N-2O1S0	His->Tyr
C-1H1N-1O1S0	His->Gln
C6H3N1O1S0	NIC
C0H5N1O0S0	His->Arg
C0H4N-2O0S0	His->Xle
C-3H-6N0O0S0	Xle->Ala
C-2H-4N0O1S0	Xle->Thr
C-2H-5N1O1S0	Xle->Asn
C0H1N1O0S0	Xle->Lys
C-2H-5N-1O1S0	Lys->Thr
C-2H-6N0O1S0	Lys->Asn
C-1H-5N-1O2S0	Lys->Glu
C-1H-4N0O1S0	Lys->Gln
C-1H-3N-1O0S1	Lys->Met
C0H0N2O0S0	Lys->Arg
C0H-1N-1O0S0	Lys->Xle
C-3H-6N0O1S0	Xle->Ser
C3H-2N0O0S0	Xle->Phe
C5H-1N1O0S0	Xle->Trp
C-1H-4N0O0S0	Xle->Pro
C-1H-2N0O0S0	Xle->Val
C0H-4N2O0S0	Xle->His
C-1H-3N1O1S0	Xle->Gln
C-1H-2N0O0S1	Xle->Met
C0H1N3O0S0	Xle->Arg
C-1H-2N0O1S-1	Met->Thr
C1H3N3O0S-1	Met->Arg
C1H3N1O0S-1	Met->Lys
C1H2N0O0S-1	Met->Xle
C0H0N0O0S-1	Met->Val
C-1H-1N-1O0S0	Asn->Ser
C0H1N-1O0S0	Asn->Thr
C2H6N0O-1S0	Asn->Lys
C5H3N-1O0S0	Asn->Tyr
C2H1N1O-1S0	Asn->His
C0H-1N-1O1S0	Asn->Asp
C2H5N-1O-1S0	Asn->Xle
C-2H-2N0O1S0	Pro->Ser
C-2H-2N0O0S0	Pro->Ala
C1H0N2O0S0	Pro->His
C0H1N1O1S0	Pro->Gln
C-1H0N0O1S0	Pro->Thr
C1H5N3O0S0	Pro->Arg
C1H4N0O0S0	Pro->Xle
C0H-1N-1O-1S0	Gln->Pro
C1H4N0O-1S0	Gln->Lys
C0H-1N-1O1S0	Gln->Glu
C1H-1N1O-1S0	Gln->His
C1H4N2O-1S0	Gln->Arg
C1H3N-1O-1S0	Gln->Xle
C-3H-7N-3O1S0	Arg->Ser
C5H-2N-2O0S0	Arg->Trp
C-2H-5N-3O1S0	Arg->Thr
C-1H-5N-3O0S0	Arg->Pro
C0H0N-2O0S0	Arg->Lys
C0H-5N-1O0S0	Arg->His
C-1H-4N-2O1S0	Arg->Gln
C-1H-3N-3O0S1	Arg->Met
C-3H-7N-3O0S1	Arg->Cys
C0H-1N-3O0S0	Arg->Xle
C-4H-9N-3O0S0	Arg->Gly
C6H4N0O-1S0	Ser->Phe
C0H0N0O-1S0	Ser->Ala
C8H5N1O-1S0	Ser->Trp
C1H2N0O0S0	Ser->Thr
C1H1N1O0S0	Ser->Asn
C2H2N0O-1S0	Ser->Pro
C6H4N0O0S0	Ser->Tyr
C0H0N0O-1S1	Ser->Cys
C3H7N3O-1S0	Ser->Arg
C3H6N0O-1S0	Ser->Xle
C-1H-2N0O-1S0	Ser->Gly
C-1H-2N0O0S0	Thr->Ser
C-1H-2N0O-1S0	Thr->Ala
C0H-1N1O0S0	Thr->Asn
C2H5N1O-1S0	Thr->Lys
C1H0N0O-1S0	Thr->Pro
C1H2N0O-1S1	Thr->Met
C2H4N0O-1S0	Thr->Xle
C2H5N3O-1S0	Thr->Arg
C4H0N0O0S0	Val->Phe
C-2H-4N0O0S0	Val->Ala
C0H-2N0O2S0	Val->Glu
C0H0N0O0S1	Val->Met
C-1H-4N0O2S0	Val->Asp
C1H2N0O0S0	Val->Xle
C-3H-6N0O0S0	Val->Gly
C-8H-5N-1O1S0	Trp->Ser
C-8H-5N-1O0S1	Trp->Cys
C-5H2N2O0S0	Trp->Arg
C-9H-7N-1O0S0	Trp->Gly
C-5H1N-1O0S0	Trp->Xle
C0H0N0O-1S0	Tyr->Phe
C-6H-4N0O0S0	Tyr->Ser
C-5H-3N1O0S0	Tyr->Asn
C-3H-2N2O-1S0	Tyr->His
C-5H-4N0O1S0	Tyr->Asp
C-6H-4N0O-1S1	Tyr->Cys
C18H31N1O4S0	NA-LNO2
C18H33N1O4S0	NA-OA-NO2
C6H10N0O4S2	CarboxymethylDTT
C9H14N0O1S0	HNE-Delta:H(2)O
C9H14N0O2S0	4-ONE
C4H8N0O1S2	BEMAD_ST
C2H5N1O0S0	Ethanolamine
C4H8N0O2S1	BEMAD_C
C12H20N2O2S0	TMT
C10H10N3O3S1	NO_SMX_SEMD
C9H12N0O1S0	4-ONE+Delta:H(-2)O(-1)
C10H10N3O4S1	NO_SMX_SMCT
C10H9N3O4S1	NO_SMX_SIMD
C3H2N0O3S0	Malonyl
C7H4N0O4S1	3sulfo
C6H1N3O6S0	TNBS
C29H38N8O6S1	Biotin-phenacyl
C16H16N0O2S0	lapachenole
C4H3N1O2S0	maleimide
C-5H-9N-1O-1S-1	Met-loss
C-3H-7N-1O0S-1	Met-loss+Acetyl
C11H8N0O2S0	Menadione-HQ
C-2H-2N0O-2S0	Gly-loss+Amide
C3H-1N1O2S0	Arg->Npo
C5H11N1O0S0	Pentylamine
C15H25N3O2S1	Biotin:Thermo-21345
C3H4N0O2S0	Dihydroxyimidazolidine
C6H0N2O4S0	Xlink:DFDNB
C37H38N4O7S1	Cy3b-maleimide
C14H23N1O10S0	Hex(1)HexNAc(1)
C10H8N2O4S0	Xlink:BMOE
C21H37N5O6S1	Biotin:Thermo-21360
C20H32N6O8S0	EQIGG
C5H4N5O1S0	cGMP+RMP-loss
C7H12N2O1S0	mTRAQ
C16H10N0O4S0	Arg2PG
C10H23N3O0S0	spermine
C3H2N0O1S0	MG-H1
C2H0N0O1S0	G-H1
C39H48N4O15S4	DyLight-maleimide
C32H58N2O15S0	Methyl-PEO12-Maleimide
C20H21N3O5S0	MDCC
C23H37N9O10S0	QQQTGG
C23H36N8O11S0	QEQTGG
C6H4N0O2S0	HydroxymethylOP
C34H45N7O7S1	Biotin:Thermo-21325
C26H42N8O7S0	Biotin-PEG-PRA
C-1H-3N3O0S-1	Met->Aha
C1H-2N0O0S-1	Met->Hpg
C17H24N0O9S0	4AcAllylGal
C-1H-4N0O1S1	Lys->CamCys
C-4H-1N1O1S1	Phe->CamCys
C-1H-2N0O1S1	Leu->MetOx
C-1H-3N-1O1S1	Lys->MetOx
C6H10N0O6S0	Galactosyl
C17H27N3O3S0	Xlink:SMCC[321]
C10H16N2O4S0	Bacillosamine
C9H14N1O1S1	MTSL
C25H45N5O4S1	HNE-BAHAH
C3H4N0O2S0	Ethoxyformyl
C4H4N0O3S0	Methylmalonylation
C35H52N10O9S2	AROD
C1H3N1O0S-1	Cys->methylaminoAla
C2H5N1O0S-1	Cys->ethylaminoAla
C2H5N1O-1S0	ethylamino
C2H4N0O0S1	MercaptoEthanol
C27H32N5O3S0	Atto495Maleimide
C19H30N6O10S0	AMTzHexNAc2
C2H3N-1O1S0	Ethyl+Deamidated
C37H55N11O12S0	VFQQQTGG
C53H81N13O19S0	VIEVYQEQTGG
C6H3N2O4S1	DNPS
C22H26N4O5S1	SulfoGMBS
C13H21N3O3S0	DimethylamineGMBS
C20H26N0O3S0	LG-anhydrolactam
C20H28N0O3S0	LG-pyrrole
C20H26N0O2S0	LG-anhyropyrrole
C6H8N0O4S0	3-deoxyglucosone
C4H4N0O4S0	2-succinyl
C3H3N1O-1S0	Propargylamine
C90H137N21O37S1	SUMO2135
C150H224N38O60S1	SUMO3549
C10H9N1O1S0	serotonylation
C8H7N1O0S1	BITC
C2H4N1O1S0	Carbofuran
C9H9N1O0S1	PEITC
C6H9N1O2S1	thioacylPA
C37H59N7O23S0	maleimide3
C49H79N7O33S0	maleimide5
C22H27N7O4S0	Puromycin
C6H8N0O5S0	glucosone
C14H25N3O2S1	cysTMT
C0H-1N-1O0S0	ISD_z+2_ion
C0H3N1O0S0	Ammonium
C20H27N5O5S1	Biotin:Sigma-B1267
C0H1N1O3S1	sulfo+amino
C4H5N5O1S-1	AHA-Alkyne
C26H37N11O14S-1	AHA-Alkyne-KDDDD
C22H16N0O11S0	EGCG1
C15H11N0O6S0	EGCG2
C1H0N0O0S0	Thiazolidine
C89H122N18O31S1	DEDGFLYMVYASQETFG
C23H33N5O7S1	Biotin:Invitrogen-M1602
C8H12N0O3S0	Xlink:DSS[156]
C6H9N1O1S0	DMPO
C3H5N1O2S0	glycidamide
C16H27N3O3S0	Ahx2+Hsl
C8H10N0O2S0	ICDID
C10H12N0O7S0	Xlink:EGS[244]
C4H4N0O5S0	Xlink:DST[132]
C6H8N0O3S2	Xlink:DTSSP[192]
C12H15N1O4S0	Xlink:SMCC[237]
C7H5N1O2S0	2-nitrobenzyl
C7H12N2O1S0	Xlink:DMP[140]
C4H5N1O3S0	Xlink:EGS[115]
C9H6N2O0S1	Thiadiazole
C10H16N2O2S0	Biotin:Thermo-88310
C23H37N5O8S1	Biotin:Thermo-21901+H2O
C4H9N1O0S0	Deoxyhypusine
C6H11N1O0S0	Acetyldeoxyhypusine
C6H11N1O1S0	Acetylhypusine
C0H0N0O0S1	Ala->Cys
C6H4N0O0S0	Ala->Phe
C3H2N2O0S0	Ala->His
C3H6N0O0S0	Ala->Xle
C3H7N1O0S0	Ala->Lys
C2H4N0O0S1	Ala->Met
C1H1N1O1S0	Ala->Asn
C2H3N1O1S0	Ala->Gln
C3H7N3O0S0	Ala->Arg
C8H5N1O0S0	Ala->Trp
C6H4N0O1S0	Ala->Tyr
C0H0N0O0S-1	Cys->Ala
C1H0N0O2S-1	Cys->Asp
C2H2N0O2S-1	Cys->Glu
C3H2N2O0S-1	Cys->His
C3H6N0O0S-1	Cys->Xle
C3H7N1O0S-1	Cys->Lys
C2H4N0O0S0	Cys->Met
C1H1N1O1S-1	Cys->Asn
C2H2N0O0S-1	Cys->Pro
C2H3N1O1S-1	Cys->Gln
C1H2N0O1S-1	Cys->Thr
C2H4N0O0S-1	Cys->Val
C-1H0N0O-2S1	Asp->Cys
C5H4N0O-2S0	Asp->Phe
C2H6N0O-2S0	Asp->Xle
C2H7N1O-2S0	Asp->Lys
C1H4N0O-2S1	Asp->Met
C1H2N0O-2S0	Asp->Pro
C1H3N1O-1S0	Asp->Gln
C2H7N3O-2S0	Asp->Arg
C-1H0N0O-1S0	Asp->Ser
C0H2N0O-1S0	Asp->Thr
C7H5N1O-2S0	Asp->Trp
C-2H-2N0O-2S1	Glu->Cys
C4H2N0O-2S0	Glu->Phe
C1H0N2O-2S0	Glu->His
C1H4N0O-2S0	Glu->Xle
C0H2N0O-2S1	Glu->Met
C-1H-1N1O-1S0	Glu->Asn
C0H0N0O-2S0	Glu->Pro
C1H5N3O-2S0	Glu->Arg
C-2H-2N0O-1S0	Glu->Ser
C-1H0N0O-1S0	Glu->Thr
C6H3N1O-2S0	Glu->Trp
C4H2N0O-1S0	Glu->Tyr
C-6H-4N0O0S0	Phe->Ala
C-5H-4N0O2S0	Phe->Asp
C-4H-2N0O2S0	Phe->Glu
C-7H-6N0O0S0	Phe->Gly
C-3H-2N2O0S0	Phe->His
C-3H3N1O0S0	Phe->Lys
C-4H0N0O0S1	Phe->Met
C-5H-3N1O1S0	Phe->Asn
C-4H-2N0O0S0	Phe->Pro
C-4H-1N1O1S0	Phe->Gln
C-3H3N3O0S0	Phe->Arg
C-5H-2N0O1S0	Phe->Thr
C2H1N1O0S0	Phe->Trp
C7H6N0O0S0	Gly->Phe
C4H4N2O0S0	Gly->His
C4H8N0O0S0	Gly->Xle
C4H9N1O0S0	Gly->Lys
C3H6N0O0S1	Gly->Met
C2H3N1O1S0	Gly->Asn
C3H4N0O0S0	Gly->Pro
C3H5N1O1S0	Gly->Gln
C2H4N0O1S0	Gly->Thr
C7H6N0O1S0	Gly->Tyr
C-3H-2N-2O0S0	His->Ala
C-3H-2N-2O0S1	His->Cys
C-1H0N-2O2S0	His->Glu
C3H2N-2O0S0	His->Phe
C-4H-4N-2O0S0	His->Gly
C0H5N-1O0S0	His->Lys
C-1H2N-2O0S1	His->Met
C-3H-2N-2O1S0	His->Ser
C-2H0N-2O1S0	His->Thr
C-1H2N-2O0S0	His->Val
C5H3N-1O0S0	His->Trp
C-3H-6N0O0S1	Xle->Cys
C-2H-6N0O2S0	Xle->Asp
C-1H-4N0O2S0	Xle->Glu
C-4H-8N0O0S0	Xle->Gly
C3H-2N0O1S0	Xle->Tyr
C-3H-7N-1O0S0	Lys->Ala
C-3H-7N-1O0S1	Lys->Cys
C-2H-7N-1O2S0	Lys->Asp
C3H-3N-1O0S0	Lys->Phe
C-4H-9N-1O0S0	Lys->Gly
C0H-5N1O0S0	Lys->His
C-1H-5N-1O0S0	Lys->Pro
C-3H-7N-1O1S0	Lys->Ser
C-1H-3N-1O0S0	Lys->Val
C5H-2N0O0S0	Lys->Trp
C3H-3N-1O1S0	Lys->Tyr
C-2H-4N0O0S-1	Met->Ala
C-2H-4N0O0S0	Met->Cys
C-1H-4N0O2S-1	Met->Asp
C0H-2N0O2S-1	Met->Glu
C4H0N0O0S-1	Met->Phe
C-3H-6N0O0S-1	Met->Gly
C1H-2N2O0S-1	Met->His
C-1H-3N1O1S-1	Met->Asn
C0H-2N0O0S-1	Met->Pro
C0H-1N1O1S-1	Met->Gln
C-2H-4N0O1S-1	Met->Ser
C6H1N1O0S-1	Met->Trp
C4H0N0O1S-1	Met->Tyr
C-1H-1N-1O-1S0	Asn->Ala
C-1H-1N-1O-1S1	Asn->Cys
C1H1N-1O1S0	Asn->Glu
C5H3N-1O-1S0	Asn->Phe
C-2H-3N-1O-1S0	Asn->Gly
C1H3N-1O-1S1	Asn->Met
C1H1N-1O-1S0	Asn->Pro
C1H2N0O0S0	Asn->Gln
C2H6N2O-1S0	Asn->Arg
C1H3N-1O-1S0	Asn->Val
C7H4N0O-1S0	Asn->Trp
C-2H-2N0O0S1	Pro->Cys
C-1H-2N0O2S0	Pro->Asp
C0H0N0O2S0	Pro->Glu
C4H2N0O0S0	Pro->Phe
C-3H-4N0O0S0	Pro->Gly
C1H5N1O0S0	Pro->Lys
C0H2N0O0S1	Pro->Met
C-1H-1N1O1S0	Pro->Asn
C0H2N0O0S0	Pro->Val
C6H3N1O0S0	Pro->Trp
C4H2N0O1S0	Pro->Tyr
C-2H-3N-1O-1S0	Gln->Ala
C-2H-3N-1O-1S1	Gln->Cys
C-1H-3N-1O1S0	Gln->Asp
C4H1N-1O-1S0	Gln->Phe
C-3H-5N-1O-1S0	Gln->Gly
C0H1N-1O-1S1	Gln->Met
C-1H-2N0O0S0	Gln->Asn
C-2H-3N-1O0S0	Gln->Ser
C-1H-1N-1O0S0	Gln->Thr
C0H1N-1O-1S0	Gln->Val
C6H2N0O-1S0	Gln->Trp
C4H1N-1O0S0	Gln->Tyr
C-3H-7N-3O0S0	Arg->Ala
C-2H-7N-3O2S0	Arg->Asp
C-1H-5N-3O2S0	Arg->Glu
C-2H-6N-2O1S0	Arg->Asn
C-1H-3N-3O0S0	Arg->Val
C3H-3N-3O1S0	Arg->Tyr
C3H-3N-3O0S0	Arg->Phe
C1H0N0O1S0	Ser->Asp
C2H2N0O1S0	Ser->Glu
C3H2N2O-1S0	Ser->His
C3H7N1O-1S0	Ser->Lys
C2H4N0O-1S1	Ser->Met
C2H3N1O0S0	Ser->Gln
C2H4N0O-1S0	Ser->Val
C-1H-2N0O-1S1	Thr->Cys
C0H-2N0O1S0	Thr->Asp
C1H0N0O1S0	Thr->Glu
C5H2N0O-1S0	Thr->Phe
C-2H-4N0O-1S0	Thr->Gly
C2H0N2O-1S0	Thr->His
C1H1N1O0S0	Thr->Gln
C1H2N0O-1S0	Thr->Val
C7H3N1O-1S0	Thr->Trp
C5H2N0O0S0	Thr->Tyr
C-2H-4N0O0S1	Val->Cys
C1H-2N2O0S0	Val->His
C1H3N1O0S0	Val->Lys
C-1H-3N1O1S0	Val->Asn
C0H-2N0O0S0	Val->Pro
C0H-1N1O1S0	Val->Gln
C1H3N3O0S0	Val->Arg
C-2H-4N0O1S0	Val->Ser
C-1H-2N0O1S0	Val->Thr
C6H1N1O0S0	Val->Trp
C4H0N0O1S0	Val->Tyr
C-8H-5N-1O0S0	Trp->Ala
C-7H-5N-1O2S0	Trp->Asp
C-6H-3N-1O2S0	Trp->Glu
C-2H-1N-1O0S0	Trp->Phe
C-5H-3N1O0S0	Trp->His
C-5H2N0O0S0	Trp->Lys
C-6H-1N-1O0S1	Trp->Met
C-7H-4N0O1S0	Trp->Asn
C-6H-3N-1O0S0	Trp->Pro
C-6H-2N0O1S0	Trp->Gln
C-7H-3N-1O1S0	Trp->Thr
C-6H-1N-1O0S0	Trp->Val
C-2H-1N-1O1S0	Trp->Tyr
C-6H-4N0O-1S0	Tyr->Ala
C-4H-2N0O1S0	Tyr->Glu
C-7H-6N0O-1S0	Tyr->Gly
C-3H3N1O-1S0	Tyr->Lys
C-4H0N0O-1S1	Tyr->Met
C-4H-2N0O-1S0	Tyr->Pro
C-4H-1N1O0S0	Tyr->Gln
C-3H3N3O-1S0	Tyr->Arg
C-5H-2N0O0S0	Tyr->Thr
C-4H0N0O-1S0	Tyr->Val
C2H1N1O-1S0	Tyr->Trp
C-3H2N0O-1S0	Tyr->Xle
C7H9N5O2S0	AHA-SS
C9H12N6O3S0	AHA-SS_CAM
C25H36N6O4S2	Biotin:Thermo-33033
C25H34N6O4S2	Biotin:Thermo-33033-H
C5H6N0O4S0	2-monomethylsuccinyl
C7H6N0O1S0	Saligenin
C4H8N2O1S0	Ub-Br2
C7H13N2O3S0	Ub-VME
C9H14N3O2S0	Ub-amide
C31H29N6O7S0	Ub-fluorescein
C6H8N0O4S0	2-dimethylsuccinyl
C2H3N1O1S0	Gly
C9H13N3O5S0	pupylation
C4H7N1O2S1	HCysteinyl
C47H60N23O10S0	UgiJoullie
C4H7N1O1S1	HCysThiolactone
C7H10N2O2S0	UgiJoullieProGly
C13H11N3O1S0	Dipyridyl
C4H2N0O1S0	Furan
C8H4N0O2S0	Difuran
C18H17N1O1S0	BMP-piperidinol
C14H20N4O4S0	UgiJoullieProGlyProGly
C-6H-12N-4O-1S0	Arg-loss
C6H12N4O1S0	Arg
C25H40N2O18S1	IMEHex(2)NeuAc(1)
C4H6N0O1S0	Butyryl
C4H6N2O2S0	Dicarbamidomethyl
C9H14N4O4S0	GGQ
C13H21N5O6S0	QTGG
C6H12N2O1S0	Lys
C44H68N4O32S0	NeuAc
C11H17N1O9S0	NeuGc
C3H6N0O0S0	Propyl
C9H8N0O1S0	Propiophenone
C7H4N0O2S0	PS_Hapten
C37H45N4O9S2	Cy3-maleimide
C3H6N0O1S0	Delta:H(6)C(3)O(1)
C6H8N0O1S0	Delta:H(8)C(6)O(1)
C13H22N4O2S1	biotinAcrolein298
C18H19N1O1S0	MM-diphenylpentanone
C18H18N0O2S0	EHD-diphenylpentanone
C8H8N2O0S0	benzylguanidine
C9H10N2O1S0	CarboxymethylDMAP
C23H39N5O9S1	Biotin:Thermo-21901+2H2O
C9H15N3O3S0	Xlink:BuUrBu[213]
C32H25N2O0S0	bisANS-sulfonates
C6H2N2O4S0	DNCB_hapten
C6H7N1O2S1	NEMsulfur
C0H0N0O2S1	SulfurDioxide
C6H9N1O3S1	NEMsulfurWater
C6H13N1O2S0	HN3_mustard
C5H11N1O1S0	HN2_mustard
C4H4N0O1S0	Crotonyl
C0H-4N0O-1S0	azole
C41H71N5O16S1	Biotin:Thermo-21911
C16H28N4O3S0	iodoTMT
C36H60N0O27S0	dHex(1)Hex(1)
C3H6N0O2S1	methylsulfonylethyl
C54H90N0O42S0	dHex(1)Hex(2)
C24H40N0O19S0	dHex(1)Hex(3)
C30H50N0O24S0	dHex(1)Hex(4)
C36H60N0O29S0	dHex(1)Hex(5)
C42H70N0O34S0	dHex(1)Hex(6)
C4H8N0O2S1	ethylsulfonylethyl
C8H8N0O2S1	phenylsulfonylethyl
C-1H-2N0O3S0	Homocysteic_acid
C0H1N1O0S0	Hydroxamic_acid
C6H7N1O3S0	Oxidation+NEM
C27H21N1O7S0	NHS-fluorescein
C8H7N1O1S0	Iodoacetanilide
C13H20N2O6S2	Dap-DSP
C11H17N1O7S0	MurNAc
C72H107N17O31S0	EEEDVIEVYQEQTGG
C69H102N18O30S0	EDEDTIDVFQQQTGG
C84H136N6O61S0	Hex(5)HexNAc(4)NeuAc(2)
C73H119N5O53S0	Hex(5)HexNAc(4)NeuAc(1)
C79H129N5O57S0	dHex(1)Hex(5)HexNAc(4)NeuAc(1)
C90H146N6O65S0	dHex(1)Hex(5)HexNAc(4)NeuAc(2)
C8H13N1O8S1	s-GlcNAc
C7H16N2O0S0	spermidine
C21H35N3O7S1	Biotin:Thermo-21330
C16H26N0O13S0	Hex(1)Pent(2)
C5H8N0O4S0	Pentose
C11H18N0O9S0	Hex(1)Pent(1)
C12H18N0O11S0	Hex(1)HexA(1)
C42H69N3O39S3	Hex(1)HexNAc(1)Sulf(1)
C17H27N1O13S0	Hex(1)NeuAc(1)
C17H27N1O14S0	Hex(1)NeuGc(1)
C24H39N3O15S0	HexNAc(3)
C19H30N2O13S0	HexNAc(1)NeuAc(1)
C19H30N2O14S0	HexNAc(1)NeuGc(1)
C23H37N1O18S0	Hex(2)NeuAc(1)
C21H35N1O14S0	Hex(1)HexNAc(1)dHex(1)Me(1)
C22H37N1O14S0	Hex(1)HexNAc(1)dHex(1)Me(2)
C8H13N1O2S0	Xlink:DSS[155]
C20H33N1O15S0	Hex(2)HexNAc(1)
C20H31N1O16S0	Hex(1)HexA(1)HexNAc(1)
C21H35N1O15S0	Hex(2)HexNAc(1)Me(1)
C21H34N0O17S0	Hex(1)Pent(3)
C22H35N1O17S0	Hex(1)NeuAc(1)Pent(1)
C20H33N1O18S1	Hex(2)HexNAc(1)Sulf(1)
C24H40N0O18S0	dHex(2)Hex(2)
C24H38N0O20S0	dHex(1)Hex(2)HexA(1)
C22H36N2O18S1	Hex(1)HexNAc(2)Sulf(1)
C24H40N0O20S0	Hex(4)
C39H64N2O28S0	dHex(1)Hex(2)HexNAc(2)Pent(1)
C39H63N3O28S0	Hex(2)HexNAc(2)NeuAc(1)
C39H64N2O29S0	Hex(3)HexNAc(2)Pent(1)
C40H66N2O30S0	Hex(4)HexNAc(2)
C43H71N1O33S0	dHex(1)Hex(4)HexNAc(1)Pent(1)
C45H74N2O33S0	dHex(1)Hex(3)HexNAc(2)Pent(1)
C45H73N3O33S0	Hex(3)HexNAc(2)NeuAc(1)
C45H74N2O34S0	Hex(4)HexNAc(2)Pent(1)
C47H77N3O34S0	Hex(3)HexNAc(3)Pent(1)
C102H168N4O76S0	dHex(1)Hex(4)HexNAc(2)Pent(1)
C50H83N1O40S0	Hex(7)HexNAc(1)
C51H83N3O38S0	Hex(4)HexNAc(2)NeuAc(1)
C52H86N2O39S0	dHex(1)Hex(5)HexNAc(2)
C53H87N3O38S0	dHex(1)Hex(3)HexNAc(3)Pent(1)
C50H82N4O38S1	Hex(3)HexNAc(4)Sulf(1)
C52H86N2O40S0	Hex(6)HexNAc(2)
C53H87N3O39S0	Hex(4)HexNAc(3)Pent(1)
C54H89N3O39S0	dHex(1)Hex(4)HexNAc(3)
C54H89N3O40S0	Hex(5)HexNAc(3)
C55H90N4O39S0	Hex(3)HexNAc(4)Pent(1)
C108H178N6O84S2	dHex(1)Hex(4)HexNAc(3)Sulf(1)
C57H94N2O43S0	dHex(1)Hex(5)HexNAc(2)Pent(1)
C56H93N1O45S0	Hex(8)HexNAc(1)
C58H95N3O42S0	dHex(1)Hex(3)HexNAc(3)Pent(2)
C59H97N3O42S0	dHex(2)Hex(3)HexNAc(3)Pent(1)
C56H92N4O42S1	dHex(1)Hex(3)HexNAc(4)Sulf(1)
C58H96N2O44S0	dHex(1)Hex(6)HexNAc(2)
C59H97N3O43S0	dHex(1)Hex(4)HexNAc(3)Pent(1)
C56H92N4O43S1	Hex(4)HexNAc(4)Sulf(1)
C58H96N2O45S0	Hex(7)HexNAc(2)
C60H99N3O43S0	dHex(2)Hex(4)HexNAc(3)
C59H97N3O44S0	Hex(5)HexNAc(3)Pent(1)
C59H96N4O44S0	Hex(4)HexNAc(3)NeuGc(1)
C60H99N3O44S0	dHex(1)Hex(5)HexNAc(3)
C61H100N4O43S0	dHex(1)Hex(3)HexNAc(4)Pent(1)
C58H95N5O43S1	Hex(3)HexNAc(5)Sulf(1)
C60H99N3O45S0	Hex(6)HexNAc(3)
C61H99N5O43S0	Hex(3)HexNAc(4)NeuAc(1)
C61H100N4O44S0	Hex(4)HexNAc(4)Pent(1)
C126H208N8O88S0	Hex(4)HexNAc(4)Me(2)Pent(1)
C63H103N3O46S0	dHex(1)Hex(3)HexNAc(3)Pent(3)
C60H99N3O47S1	dHex(1)Hex(5)HexNAc(3)Sulf(1)
C64H105N3O46S0	dHex(2)Hex(3)HexNAc(3)Pent(2)
C128H210N10O90S0	Hex(4)HexNAc(5)
C65H107N3O46S0	dHex(3)Hex(3)HexNAc(3)Pent(1)
C65H107N3O47S0	dHex(2)Hex(4)HexNAc(3)Pent(1)
C62H102N4O47S1	dHex(1)Hex(4)HexNAc(4)Sulf(1)
C64H106N2O49S0	dHex(1)Hex(7)HexNAc(2)
C65H106N4O47S0	dHex(1)Hex(4)HexNAc(3)NeuAc(1)
C124H204N8O96S2	Hex(5)HexNAc(4)Sulf(1)
C64H106N2O50S0	Hex(8)HexNAc(2)
C66H108N4O47S0	dHex(1)Hex(3)HexNAc(4)Pent(2)
C65H106N4O48S0	dHex(1)Hex(4)HexNAc(3)NeuGc(1)
C67H110N4O47S0	dHex(2)Hex(3)HexNAc(4)Pent(1)
C64H105N5O47S1	dHex(1)Hex(3)HexNAc(5)Sulf(1)
C66H109N3O49S0	dHex(1)Hex(6)HexNAc(3)
C67H109N5O47S0	dHex(1)Hex(3)HexNAc(4)NeuAc(1)
C68H112N4O47S0	dHex(3)Hex(3)HexNAc(4)
C67H110N4O48S0	dHex(1)Hex(4)HexNAc(4)Pent(1)
C64H105N5O48S1	Hex(4)HexNAc(5)Sulf(1)
C66H109N3O50S0	Hex(7)HexNAc(3)
C65H106N4O50S1	dHex(1)Hex(4)HexNAc(3)NeuAc(1)Sulf(1)
C69H114N4O49S0	Hex(5)HexNAc(4)Me(2)Pent(1)
C66H108N6O48S1	Hex(3)HexNAc(6)Sulf(1)
C66H109N3O52S1	dHex(1)Hex(6)HexNAc(3)Sulf(1)
C70H115N5O49S0	dHex(1)Hex(4)HexNAc(5)
C66H107N3O53S1	dHex(1)Hex(5)HexA(1)HexNAc(3)Sulf(1)
C142H236N8O100S0	Hex(6)HexNAc(4)Me(3)
C68H112N4O51S1	dHex(2)Hex(4)HexNAc(4)Sulf(1)
C70H113N5O51S0	Hex(4)HexNAc(3)NeuAc(2)
C71H116N4O51S0	dHex(1)Hex(3)HexNAc(4)Pent(3)
C71H117N3O52S0	dHex(2)Hex(5)HexNAc(3)Pent(1)
C68H112N4O52S1	dHex(1)Hex(5)HexNAc(4)Sulf(1)
C72H118N4O51S0	dHex(2)Hex(3)HexNAc(4)Pent(2)
C71H116N4O52S0	dHex(1)Hex(5)HexNAc(3)NeuAc(1)
C66H108N6O51S2	Hex(3)HexNAc(6)Sulf(2)
C70H116N2O55S0	Hex(9)HexNAc(2)
C72H118N6O50S0	Hex(4)HexNAc(6)
C73H120N4O51S0	dHex(3)Hex(3)HexNAc(4)Pent(1)
C71H116N4O53S0	dHex(1)Hex(5)HexNAc(3)NeuGc(1)
C73H120N4O52S0	dHex(2)Hex(4)HexNAc(4)Pent(1)
C70H115N5O52S1	dHex(1)Hex(4)HexNAc(5)Sulf(1)
C72H119N3O54S0	dHex(1)Hex(7)HexNAc(3)
C73H120N4O53S0	dHex(1)Hex(5)HexNAc(4)Pent(1)
C66H107N3O56S2	dHex(1)Hex(5)HexA(1)HexNAc(3)Sulf(2)
C74H121N7O50S0	Hex(3)HexNAc(7)
C74H122N4O53S0	dHex(2)Hex(5)HexNAc(4)
C71H116N4O54S1	dHex(2)Hex(4)HexNAc(3)NeuAc(1)Sulf(1)
C68H112N4O55S2	dHex(1)Hex(5)HexNAc(4)Sulf(2)
C75H124N4O53S0	dHex(1)Hex(5)HexNAc(4)Me(2)Pent(1)
C73H119N5O54S0	Hex(5)HexNAc(4)NeuGc(1)
C72H118N6O52S1	dHex(1)Hex(3)HexNAc(6)Sulf(1)
C74H122N4O54S0	dHex(1)Hex(6)HexNAc(4)
C71H116N4O55S1	dHex(1)Hex(5)HexNAc(3)NeuAc(1)Sulf(1)
C74H122N4O55S0	Hex(7)HexNAc(4)
C71H116N4O56S1	dHex(1)Hex(5)HexNAc(3)NeuGc(1)Sulf(1)
C75H122N6O53S0	Hex(4)HexNAc(5)NeuAc(1)
C76H126N4O54S0	Hex(6)HexNAc(4)Me(3)Pent(1)
C72H119N3O57S1	dHex(1)Hex(7)HexNAc(3)Sulf(1)
C152H250N10O108S0	dHex(1)Hex(5)HexNAc(5)
C73H119N5O55S1	dHex(1)Hex(4)HexNAc(4)NeuAc(1)Sulf(1)
C74H122N4O55S1	dHex(3)Hex(4)HexNAc(4)Sulf(1)
C74H121N7O53S1	Hex(3)HexNAc(7)Sulf(1)
C76H125N5O55S0	Hex(6)HexNAc(5)
C73H119N5O56S1	Hex(5)HexNAc(4)NeuAc(1)Sulf(1)
C77H125N7O53S0	Hex(3)HexNAc(6)NeuAc(1)
C78H128N6O53S0	dHex(2)Hex(3)HexNAc(6)
C25H40N2O19S0	Hex(1)HexNAc(1)NeuGc(1)
C26H43N1O19S0	dHex(1)Hex(2)HexNAc(1)
C24H39N3O18S1	HexNAc(3)Sulf(1)
C26H43N1O20S0	Hex(3)HexNAc(1)
C23H37N1O21S1	Hex(1)HexNAc(1)Kdn(1)Sulf(1)
C27H43N3O18S0	HexNAc(2)NeuAc(1)
C26H41N1O21S0	HexNAc(1)Kdn(2)
C27H45N1O20S0	Hex(3)HexNAc(1)Me(1)
C23H36N0O23S1	Hex(2)HexA(1)Pent(1)Sulf(1)
C27H43N3O19S0	HexNAc(2)NeuGc(1)
C75H120N6O63S3	Hex(1)HexNAc(1)NeuAc(1)Sulf(1)
C28H44N2O21S0	Hex(1)HexA(1)HexNAc(2)
C26H43N1O22S1	dHex(1)Hex(2)HexNAc(1)Sulf(1)
C30H49N3O19S0	dHex(1)HexNAc(3)
C29H47N1O22S0	dHex(1)Hex(1)HexNAc(1)Kdn(1)
C30H49N3O20S0	Hex(1)HexNAc(3)
C27H43N3O21S1	HexNAc(2)NeuAc(1)Sulf(1)
C30H50N0O23S0	dHex(2)Hex(3)
C26H41N1O24S1	Hex(2)HexA(1)HexNAc(1)Sulf(1)
C30H48N0O24S0	dHex(2)Hex(2)HexA(1)
C28H46N2O22S1	dHex(1)Hex(1)HexNAc(2)Sulf(1)
C31H50N2O22S0	dHex(1)Hex(1)HexNAc(1)NeuAc(1)
C28H46N2O23S1	Hex(2)HexNAc(2)Sulf(1)
C30H50N0O25S0	Hex(5)
C32H52N4O20S0	HexNAc(4)
C30H47N3O23S0	HexNAc(1)NeuGc(2)
C31H50N2O23S0	dHex(1)Hex(1)HexNAc(1)NeuGc(1)
C32H53N1O23S0	dHex(2)Hex(2)HexNAc(1)
C31H50N2O24S0	Hex(2)HexNAc(1)NeuGc(1)
C32H53N1O24S0	dHex(1)Hex(3)HexNAc(1)
C32H51N1O25S0	dHex(1)Hex(2)HexA(1)HexNAc(1)
C30H49N3O23S1	Hex(1)HexNAc(3)Sulf(1)
C32H53N1O25S0	Hex(4)HexNAc(1)
C33H53N3O23S0	Hex(1)HexNAc(2)NeuAc(1)
C33H53N3O24S0	Hex(1)HexNAc(2)NeuGc(1)
C105H171N3O78S0	dHex(2)Hex(1)HexNAc(1)Kdn(1)
C32H53N1O27S1	dHex(1)Hex(3)HexNAc(1)Sulf(1)
C36H59N3O24S0	dHex(1)Hex(1)HexNAc(3)
C32H51N1O28S1	dHex(1)Hex(2)HexA(1)HexNAc(1)Sulf(1)
C36H59N3O25S0	Hex(2)HexNAc(3)
C33H53N3O26S1	Hex(1)HexNAc(2)NeuAc(1)Sulf(1)
C36H60N0O28S0	dHex(2)Hex(4)
C27H42N2O19S0	Hex(1)HexNAc(1)NeuAc(1)Ac(1)
C37H60N2O26S0	dHex(2)HexNAc(2)Kdn(1)
C34H56N2O27S1	dHex(1)Hex(2)HexNAc(2)Sulf(1)
C38H62N4O24S0	dHex(1)HexNAc(4)
C36H57N3O27S0	Hex(1)HexNAc(1)NeuAc(1)NeuGc(1)
C37H60N2O27S0	dHex(1)Hex(1)HexNAc(2)Kdn(1)
C36H57N3O28S0	Hex(1)HexNAc(1)NeuGc(2)
C38H59N3O27S0	Hex(1)HexNAc(1)NeuAc(2)Ac(1)
C38H61N1O29S0	dHex(2)Hex(2)HexA(1)HexNAc(1)
C36H59N3O27S1	dHex(1)Hex(1)HexNAc(3)Sulf(1)
C34H53N1O31S1	Hex(2)HexA(1)NeuAc(1)Pent(1)Sulf(1)
C39H63N3O27S0	dHex(1)Hex(1)HexNAc(2)NeuAc(1)
C38H61N1O30S0	dHex(1)Hex(3)HexA(1)HexNAc(1)
C36H59N3O28S1	Hex(2)HexNAc(3)Sulf(1)
C38H63N1O30S0	Hex(5)HexNAc(1)
C40H65N5O25S0	HexNAc(5)
C40H61N3O28S0	Hex(1)HexNAc(1)NeuAc(2)Ac(2)
C39H63N3O29S0	Hex(2)HexNAc(2)NeuGc(1)
C120H192N6O90S0	dHex(1)Hex(2)HexA(1)HexNAc(2)
C38H63N1O31S1	dHex(2)Hex(3)HexNAc(1)Sulf(1)
C41H66N4O28S0	Hex(1)HexNAc(3)NeuAc(1)
C42H69N3O28S0	dHex(2)Hex(1)HexNAc(3)
C41H66N4O29S0	Hex(1)HexNAc(3)NeuGc(1)
C39H63N3O30S1	dHex(1)Hex(1)HexNAc(2)NeuAc(1)Sulf(1)
C38H61N1O33S1	dHex(1)Hex(3)HexA(1)HexNAc(1)Sulf(1)
C42H67N3O30S0	dHex(1)Hex(1)HexA(1)HexNAc(3)
C39H63N3O31S1	Hex(2)HexNAc(2)NeuAc(1)Sulf(1)
C40H66N2O31S1	dHex(2)Hex(2)HexNAc(2)Sulf(1)
C43H70N2O31S0	dHex(2)Hex(1)HexNAc(2)Kdn(1)
C44H72N4O29S0	dHex(1)Hex(1)HexNAc(4)
C44H72N4O30S0	Hex(2)HexNAc(4)
C42H67N3O33S0	Hex(2)HexNAc(1)NeuGc(2)
C44H73N1O33S0	dHex(2)Hex(4)HexNAc(1)
C44H70N4O31S0	Hex(1)HexNAc(2)NeuAc(2)
C45H73N3O31S0	dHex(2)Hex(1)HexNAc(2)NeuAc(1)
C42H69N3O32S1	dHex(1)Hex(2)HexNAc(3)Sulf(1)
C46H75N5O29S0	dHex(1)HexNAc(5)
C45H73N3O32S0	dHex(2)Hex(1)HexNAc(2)NeuGc(1)
C46H76N2O32S0	dHex(3)Hex(2)HexNAc(2)
C42H69N3O33S1	Hex(3)HexNAc(3)Sulf(1)
C40H66N2O34S2	dHex(2)Hex(2)HexNAc(2)Sulf(2)
C45H73N3O33S0	dHex(1)Hex(2)HexNAc(2)NeuGc(1)
C47H76N4O32S0	dHex(1)Hex(1)HexNAc(3)NeuAc(1)
C138H222N6O105S0	dHex(1)Hex(3)HexA(1)HexNAc(2)
C47H76N4O33S0	dHex(1)Hex(1)HexNAc(3)NeuGc(1)
C44H70N4O34S1	Hex(1)HexNAc(2)NeuAc(2)Sulf(1)
C44H71N1O37S1	dHex(2)Hex(3)HexA(1)HexNAc(1)Sulf(1)
C47H74N4O34S0	Hex(1)HexNAc(1)NeuAc(3)
C47H76N4O34S0	Hex(2)HexNAc(3)NeuGc(1)
C45H73N3O35S1	dHex(1)Hex(2)HexNAc(2)NeuAc(1)Sulf(1)
C49H80N2O35S0	dHex(3)Hex(1)HexNAc(2)Kdn(1)
C46H76N2O36S1	dHex(2)Hex(3)HexNAc(2)Sulf(1)
C49H80N2O36S0	dHex(2)Hex(2)HexNAc(2)Kdn(1)
C46H74N2O37S1	dHex(2)Hex(2)HexA(1)HexNAc(2)Sulf(1)
C50H82N4O34S0	dHex(1)Hex(2)HexNAc(4)
C47H74N4O37S0	Hex(1)HexNAc(1)NeuGc(3)
C47H76N4O35S1	dHex(1)Hex(1)HexNAc(3)NeuAc(1)Sulf(1)
C46H74N2O38S1	dHex(1)Hex(3)HexA(1)HexNAc(2)Sulf(1)
C50H80N4O35S0	dHex(1)Hex(1)HexNAc(2)NeuAc(2)
C51H83N3O35S0	dHex(3)HexNAc(3)Kdn(1)
C47H76N4O36S1	Hex(2)HexNAc(3)NeuAc(1)Sulf(1)
C48H79N3O36S1	dHex(2)Hex(2)HexNAc(3)Sulf(1)
C52H85N5O33S0	dHex(2)HexNAc(5)
C50H80N4O36S0	Hex(2)HexNAc(2)NeuAc(2)
C51H83N3O36S0	dHex(2)Hex(2)HexNAc(2)NeuAc(1)
C48H79N3O37S1	dHex(1)Hex(3)HexNAc(3)Sulf(1)
C51H83N3O37S0	dHex(2)Hex(2)HexNAc(2)NeuGc(1)
C52H85N5O35S0	Hex(2)HexNAc(5)
C51H83N3O38S0	dHex(1)Hex(3)HexNAc(2)NeuGc(1)
C52H83N5O36S0	Hex(1)HexNAc(3)NeuAc(2)
C53H86N4O37S0	dHex(1)Hex(2)HexNAc(3)NeuAc(1)
C54H89N3O37S0	dHex(3)Hex(2)HexNAc(3)
C156H252N6O120S0	dHex(1)Hex(4)HexA(1)HexNAc(2)
C53H86N4O38S0	Hex(3)HexNAc(3)NeuAc(1)
C52H82N2O41S0	dHex(1)Hex(3)HexA(2)HexNAc(2)
C50H80N4O39S1	Hex(2)HexNAc(2)NeuAc(2)Sulf(1)
C51H83N3O39S1	dHex(2)Hex(2)HexNAc(2)NeuAc(1)Sulf(1)
C53H86N4O39S0	Hex(3)HexNAc(3)NeuGc(1)
C55H90N2O39S0	dHex(4)Hex(1)HexNAc(2)Kdn(1)
C55H90N2O40S0	dHex(3)Hex(2)HexNAc(2)Kdn(1)
C52H84N2O41S1	dHex(3)Hex(2)HexA(1)HexNAc(2)Sulf(1)
C55H89N5O38S0	Hex(2)HexNAc(4)NeuAc(1)
C56H92N4O38S0	dHex(2)Hex(2)HexNAc(4)
C52H84N2O42S1	dHex(2)Hex(3)HexA(1)HexNAc(2)Sulf(1)
C57H93N3O39S0	dHex(4)HexNAc(3)Kdn(1)
C53H84N4O42S0	Hex(2)HexNAc(1)NeuGc(3)
C56H91N1O42S0	dHex(4)Hex(1)HexNAc(1)Kdn(2)
C53H86N4O40S1	dHex(1)Hex(2)HexNAc(3)NeuAc(1)Sulf(1)
C56H90N4O40S0	dHex(1)Hex(2)HexNAc(2)NeuAc(2)
C57H93N3O40S0	dHex(3)Hex(1)HexNAc(3)Kdn(1)
C53H86N4O41S1	Hex(3)HexNAc(3)NeuAc(1)Sulf(1)
C56H90N4O41S0	Hex(3)HexNAc(2)NeuAc(2)
C53H86N4O42S1	Hex(3)HexNAc(3)NeuGc(1)Sulf(1)
C56H90N4O42S0	dHex(1)Hex(2)HexNAc(2)NeuGc(2)
C57H93N3O42S0	dHex(2)Hex(3)HexNAc(2)NeuGc(1)
C54H87N3O43S1	dHex(1)Hex(3)HexA(1)HexNAc(3)Sulf(1)
C58H93N5O41S0	Hex(2)HexNAc(3)NeuAc(2)
C59H96N4O41S0	dHex(2)Hex(2)HexNAc(3)NeuAc(1)
C60H99N3O41S0	dHex(4)Hex(2)HexNAc(3)
C58H93N5O42S0	Hex(2)HexNAc(3)NeuAc(1)NeuGc(1)
C59H96N4O42S0	dHex(2)Hex(2)HexNAc(3)NeuGc(1)
C60H99N3O42S0	dHex(3)Hex(3)HexNAc(3)
C168H270N12O129S3	dHex(1)Hex(2)HexNAc(2)NeuAc(2)Sulf(1)
C58H93N5O43S0	Hex(2)HexNAc(3)NeuGc(2)
C61H100N2O44S0	dHex(4)Hex(2)HexNAc(2)Kdn(1)
C61H99N5O42S0	dHex(1)Hex(2)HexNAc(4)NeuAc(1)
C62H102N4O42S0	dHex(3)Hex(2)HexNAc(4)
C58H91N5O46S0	Hex(1)HexNAc(1)NeuGc(4)
C63H103N3O44S0	dHex(4)Hex(1)HexNAc(3)Kdn(1)
C56H92N4O46S2	Hex(4)HexNAc(4)Sulf(2)
C63H103N3O45S0	dHex(3)Hex(2)HexNAc(3)Kdn(1)
C64H105N5O43S0	dHex(2)Hex(2)HexNAc(5)
C60H97N3O47S1	dHex(2)Hex(3)HexA(1)HexNAc(3)Sulf(1)
C60H97N3O48S1	dHex(1)Hex(4)HexA(1)HexNAc(3)Sulf(1)
C64H103N5O46S0	Hex(3)HexNAc(3)NeuAc(2)
C65H106N4O46S0	dHex(2)Hex(3)HexNAc(3)NeuAc(1)
C66H109N3O46S0	dHex(4)Hex(3)HexNAc(3)
C204H333N21O129S0	dHex(2)HexNAc(7)
C64H101N5O51S0	Hex(2)HexNAc(1)NeuGc(4)
C64H103N5O49S1	Hex(3)HexNAc(3)NeuAc(2)Sulf(1)
C70H115N5O48S0	dHex(2)Hex(3)HexNAc(5)
C67H107N5O51S0	dHex(1)Hex(2)HexNAc(2)NeuGc(3)
C66H107N3O52S1	dHex(2)Hex(4)HexA(1)HexNAc(3)Sulf(1)
C69H110N6O49S0	Hex(2)HexNAc(3)NeuAc(3)
C70H113N5O50S0	dHex(1)Hex(3)HexNAc(3)NeuAc(2)
C71H116N4O50S0	dHex(3)Hex(3)HexNAc(3)NeuAc(1)
C69H110N6O52S0	Hex(2)HexNAc(3)NeuGc(3)
C216H348N18O150S0	dHex(1)Hex(2)HexNAc(4)NeuAc(2)
C69H108N6O55S0	Hex(1)HexNAc(1)NeuGc(5)
C67H109N5O54S2	Hex(4)HexNAc(4)NeuAc(1)Sulf(2)
C67H109N5O55S2	Hex(4)HexNAc(4)NeuGc(1)Sulf(2)
C76H123N5O54S0	dHex(2)Hex(3)HexNAc(3)NeuAc(2)
C67H109N5O57S3	Hex(4)HexNAc(4)NeuAc(1)Sulf(3)
C40H66N2O28S0	dHex(2)Hex(2)HexNAc(2)
C40H66N2O29S0	dHex(1)Hex(3)HexNAc(2)
C42H69N3O29S0	dHex(1)Hex(2)HexNAc(3)
C42H69N3O30S0	Hex(3)HexNAc(3)
C40H66N2O32S1	dHex(1)Hex(3)HexNAc(2)Sulf(1)
C46H76N2O33S0	dHex(2)Hex(3)HexNAc(2)
C46H76N2O34S0	dHex(1)Hex(4)HexNAc(2)
C48H79N3O33S0	dHex(2)Hex(2)HexNAc(3)
C48H79N3O34S0	dHex(1)Hex(3)HexNAc(3)
C48H79N3O35S0	Hex(4)HexNAc(3)
C52H86N2O38S0	dHex(2)Hex(4)HexNAc(2)
C54H89N3O38S0	dHex(2)Hex(3)HexNAc(3)
C58H95N5O40S0	Hex(3)HexNAc(5)
C59H96N4O43S0	Hex(4)HexNAc(3)NeuAc(1)
C62H102N4O43S0	dHex(2)Hex(3)HexNAc(4)
C64H105N5O44S0	dHex(1)Hex(3)HexNAc(5)
C66H108N6O45S0	Hex(3)HexNAc(6)
C67H109N5O48S0	Hex(4)HexNAc(4)NeuAc(1)
C68H112N4O48S0	dHex(2)Hex(4)HexNAc(4)
C68H112N4O50S0	Hex(6)HexNAc(4)
C70H115N5O50S0	Hex(5)HexNAc(5)
C72H118N6O49S0	dHex(1)Hex(3)HexNAc(6)
C73H119N5O52S0	dHex(1)Hex(4)HexNAc(4)NeuAc(1)
C74H122N4O52S0	dHex(3)Hex(4)HexNAc(4)
C75H122N6O52S0	dHex(1)Hex(3)HexNAc(5)NeuAc(1)
C76H125N5O53S0	dHex(2)Hex(4)HexNAc(5)
C19H31N7O7S0	NQIGG
C7H6N0O2S0	Carboxyethylpyrrole
C29H19N1O7S0	Fluorescein-tyramine
C80H132N4O59S0	dHex(1)Hex(7)HexNAc(4)
C25H30N2O6S0	betaFNA
C16H32N0O0S0	Brij58
C12H24N0O0S0	Brij35
C14H20N0O0S0	Triton
C18H31N0O1S0	Tween80
C12H21N0O0S0	Tween20
C4H10N1O2S0	Tris
C18H23N3O3S1	Biotin-tyramide
C18H33N7O4S0	LRGG+dimethyl
C4H6N0O2S0	GEE
C1H0N0O-1S0	Glu->pyro-Glu+Methyl
C17H31N7O4S0	LRGG+methyl
C15H24N0O1S0	NP40
C18H16N2O8S2	IASD
C15H23N3O3S3	Biotin:Thermo-21328
C0H-1N3O0S0	AzidoF
C4H9N1O0S0	Dimethylaminoethyl
C5H6N0O3S0	Gluratylation
C4H6N0O2S0	2-hydroxyisobutyrylation
C4H8N0O2S2	DTT
C11H13N0O1S0	DYn-2
C6H8N0O4S1	Xlink:DSSO[176]
C6H10N0O1S0	MesitylOxide
C12H21N1O5S0	Xlink:DSS[259]
C1H2N0O1S0	methylol
C6H9N1O3S1	Xlink:DSSO[175]
C10H17N1O6S1	Xlink:DSSO[279]
C3H2N0O1S0	Xlink:DSSO[54]
C3H2N0O1S1	Xlink:DSSO[86]
C3H4N0O2S1	Xlink:DSSO[104]
C5H5N1O2S0	Xlink:BuUrBu[111]
C4H7N1O1S0	Xlink:BuUrBu[85]
C9H14N2O4S0	Xlink:BuUrBu[214]
C13H23N3O6S0	Xlink:BuUrBu[317]
C6H6N0O3S1	Xlink:DSSO[158]
C8H10N0O2S0	Xlink:DSS[138]
C9H12N2O3S0	Xlink:BuUrBu[196]
C6H8N2O0S2	Xlink:DTBP[172]
C4H2N0O4S0	Xlink:DST[114]
C6H6N0O2S2	Xlink:DTSSP[174]
C12H13N1O3S0	Xlink:SMCC[219]
C5H7N1O2S0	Xlink:BS2G[113]
C5H6N0O3S0	Xlink:BS2G[114]
C9H15N1O5S0	Xlink:BS2G[217]
C7H13N3O0S0	Xlink:DMP[139]
C7H10N2O0S0	Xlink:DMP[122]
C2H-2N0O0S0	glyoxalAGE
C-1H-4N0O1S-1	Met->AspSA
C-1H-2N0O-1S0	Decarboxylation
C-1H-2N-2O2S0	Aspartylurea
C-1H-1N-1O2S0	Formylasparagine
C0H-2N0O1S0	Carbonyl
C0H2N0O1S0	Pro->HAVA
C17H10N0O6S0	AFB1_Dialdehyde
C0H-4N0O2S0	Delta:H(-4)O(2)
C0H-4N0O3S0	Delta:H(-4)O(3)
C0H0N0O4S0	Delta:O(4)
C3H3N0O2S0	Delta:H(3)C(3)O(2)
C5H4N0O1S0	Delta:H(4)C(5)O(1)
C8H10N0O1S0	Delta:H(10)C(8)O(1)
C7H6N0O4S0	Delta:H(6)C(7)O(4)
C12H20N0O13S1	Hex(2)Sulf(1)
C10H16N0O8S0	Pent(2)
C13H21N1O9S0	Pent(1)HexNAc(1)
C17H28N0O13S0	Hex(1)Pent(2)Me(1)
C16H26N2O13S1	HexNAc(2)Sulf(1)
C22H36N0O17S0	Hex(1)Pent(3)Me(1)
C22H36N0O18S0	Hex(2)Pent(2)
C23H38N0O18S0	Hex(2)Pent(2)Me(1)
C30H48N0O26S0	Hex(4)HexA(1)
C31H49N1O25S0	Hex(2)HexNAc(1)Pent(1)HexA(1)
C32H51N1O26S0	Hex(3)HexNAc(1)HexA(1)
C34H56N2O26S1	Hex(1)HexNAc(2)dHex(2)Sulf(1)
C36H55N3O27S0	HexA(2)HexNAc(3)
C36H58N0O30S0	dHex(1)Hex(4)HexA(1)
C36H58N0O31S0	Hex(5)HexA(1)
C38H61N1O31S0	Hex(4)HexA(1)HexNAc(1)
C44H73N1O32S0	dHex(3)Hex(3)HexNAc(1)
C44H73N1O35S0	Hex(6)HexNAc(1)
C44H72N4O32S1	Hex(1)HexNAc(4)dHex(1)Sulf(1)
C48H77N3O35S0	dHex(1)Hex(2)HexNAc(1)NeuAc(2)
C52H86N2O37S0	dHex(3)Hex(3)HexNAc(2)
C50H82N4O36S1	dHex(2)Hex(1)HexNAc(4)Sulf(1)
C50H82N4O40S2	dHex(1)Hex(2)HexNAc(4)Sulf(2)
C54H90N0O45S0	Hex(9)
C54H89N3O41S1	dHex(2)Hex(3)HexNAc(3)Sulf(1)
C59H98N2O43S0	dHex(2)Hex(5)HexNAc(2)Me(1)
C56H92N4O44S2	dHex(2)Hex(2)HexNAc(4)Sulf(2)
C62H103N1O50S0	Hex(9)HexNAc(1)
C62H102N4O48S2	dHex(3)Hex(2)HexNAc(4)Sulf(2)
C67H109N5O49S0	Hex(4)HexNAc(4)NeuGc(1)
C69H113N3O49S0	dHex(4)Hex(3)HexNAc(2)NeuAc(1)
C69H112N6O48S0	Hex(3)HexNAc(5)NeuAc(1)
C68H113N1O55S0	Hex(10)HexNAc(1)
C70H116N2O54S0	dHex(1)Hex(8)HexNAc(2)
C72H116N6O51S0	Hex(3)HexNAc(4)NeuAc(2)
C73H119N5O51S0	dHex(2)Hex(3)HexNAc(4)NeuAc(1)
C72H118N6O51S1	dHex(2)Hex(2)HexNAc(6)Sulf(1)
C75H121N5O54S0	Hex(5)HexNAc(4)NeuAc(1)Ac(1)
C75H120N6O54S0	Hex(3)HexNAc(3)NeuAc(3)
C77H123N5O55S0	Hex(5)HexNAc(4)NeuAc(1)Ac(2)
C8H18N0O3S0	Unknown:162
C13H22N0O2S0	Unknown:210
C10H16N0O5S0	Unknown:216
C9H14N0O7S0	Unknown:234
C13H28N0O4S0	Unknown:248
C10H4N1O5S1	Unknown:250
C4H8N5O7S2	Unknown:302
C12H18N0O9S0	Unknown:306
C10H14N9O6S2	Unknown:420
C13H22N4O4S1	CIGG
C61H92N14O15S2	GNLLFLACYCIGG
'''